@@ -4,10 +4,6 @@ from plotly.basedatatypes import BaseTraceType
 import funcnodes as fn
 from exposedfunctionality.function_parser.types import add_type
 
-from .plots import make_scatter, make_bar
-from .figure import make_figue, add_trace, plot
-
-
 add_type(
     go.Figure,
     "plotly.Figure",
@@ -17,6 +13,16 @@ add_type(
     "plotly.Trace",
 )
 
+from .plots import make_scatter, make_bar
+from .figure import make_figue, add_trace, plot
+
+
+FUNCNODES_RENDER_OPTIONS: fn.RenderOptions = {
+    "typemap": {
+        go.Figure: "plotly.Figure",
+    },
+}
+
 
 def figureencoder(figure: go.Figure, preview: bool = False) -> Tuple[Any, bool]:
     if isinstance(figure, go.Figure):
@@ -39,3 +45,6 @@ NODE_SHELF = fn.Shelf(
     description="A collection of functions for creating plotly plots.",
     subshelves=[],
 )
+
+
+__version__ = "0.1.1"
